# csmaps <a href="https://www.csids.no/csmaps/"><img src="man/figures/logo.png" align="right" width="120" /></a>

[![CRAN status](https://www.r-pkg.org/badges/version/csmaps)](https://cran.r-project.org/package=csmaps)
[![CRAN downloads](https://cranlogs.r-pkg.org/badges/csmaps)](https://cran.r-project.org/package=csmaps)

## Overview 

[csmaps](https://www.csids.no/csmaps/) provides preformatted maps of Norway that generally do not need geolibraries. It helps public health reporting purposes for different geographic levels in Norway.

The following geographic granularities are included: 

* County

* Municipality

* City ward (only for Oslo)

It is convenient to visualize maps with additional information, either using text labels or color palettes.

Read the introduction vignette [here](https://www.csids.no/csmaps/articles/csmaps.html) or run `help(package="csmaps")`.

## csverse

The [csverse](https://www.csids.no/packages.html) is a set of R packages developed to help solve problems that frequently occur when performing disease surveillance.

```
install.packages("attrib")
install.packages("cs9")
install.packages("csalert")
install.packages("csdata")
install.packages("csdb")
install.packages("csmaps")
install.packages("csstyle")
install.packages("cstidy")
install.packages("cstime")
install.packages("csutil")
install.packages("org")
install.packages("plnr")
```

